;; Generated package description from yaml.el  -*- no-byte-compile: t -*-
(define-package "yaml" "1.2.3" "YAML parser for Elisp" '((emacs "25.1")) :commit "f2369fb4985ed054be47ae111760ff2075dff72a" :authors '(("Zachary Romero" . "zkry@posteo.org")) :maintainer '("Zachary Romero" . "zkry@posteo.org") :keywords '("tools") :url "https://github.com/zkry/yaml.el")
